==> haskell-pretty-simple-4.1.2.0-86-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pretty-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pretty-simple
version:              4.1.2.0
visibility:           public
id:                   pretty-simple-4.1.2.0-aemf95GDbcJZS8DJ9CNZc
key:                  pretty-simple-4.1.2.0-aemf95GDbcJZS8DJ9CNZc
license:              BSD-3-Clause
copyright:            2017-2019 Dennis Gosnell
maintainer:           cdep.illabout@gmail.com
author:               Dennis Gosnell
homepage:             https://github.com/cdepillabout/pretty-simple
synopsis:             pretty printer for data types with a '\''Show'\'' instance.
description:
    Please see <https://github.com/cdepillabout/pretty-simple#readme README.md>.

category:             Text
abi:                  7acb6fea74e15682e71a4e387f6ad403
exposed:              True
exposed-modules:
    Debug.Pretty.Simple Text.Pretty.Simple Text.Pretty.Simple.Internal
    Text.Pretty.Simple.Internal.Color Text.Pretty.Simple.Internal.Expr
    Text.Pretty.Simple.Internal.ExprParser
    Text.Pretty.Simple.Internal.Printer

import-dirs:          /usr/lib/ghc-9.2.8/site-local/pretty-simple-4.1.2.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/pretty-simple-4.1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pretty-simple
hs-libraries:         HSpretty-simple-4.1.2.0-aemf95GDbcJZS8DJ9CNZc
depends:
    base-4.16.4.0 containers-0.6.5.1 mtl-2.2.2
    prettyprinter-1.7.1-9qid7zuo3B05OoqIIBWgnL
    prettyprinter-ansi-terminal-1.1.3-LWMhohC2bf65OdaY6HUJHG
    text-1.2.5.0 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-pretty-simple/html/pretty-simple.haddock

haddock-html:         /usr/share/doc/haskell-pretty-simple/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pretty-simple-4.1.2.0-87-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pretty-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pretty-simple
version:              4.1.2.0
visibility:           public
id:                   pretty-simple-4.1.2.0-3R2e5MieHhb1CbUFehFq5L
key:                  pretty-simple-4.1.2.0-3R2e5MieHhb1CbUFehFq5L
license:              BSD-3-Clause
copyright:            2017-2019 Dennis Gosnell
maintainer:           cdep.illabout@gmail.com
author:               Dennis Gosnell
homepage:             https://github.com/cdepillabout/pretty-simple
synopsis:             pretty printer for data types with a '\''Show'\'' instance.
description:
    Please see <https://github.com/cdepillabout/pretty-simple#readme README.md>.

category:             Text
abi:                  1bf2ed790332ec23625836f75e883bf6
exposed:              True
exposed-modules:
    Debug.Pretty.Simple Text.Pretty.Simple Text.Pretty.Simple.Internal
    Text.Pretty.Simple.Internal.Color Text.Pretty.Simple.Internal.Expr
    Text.Pretty.Simple.Internal.ExprParser
    Text.Pretty.Simple.Internal.Printer

import-dirs:          /usr/lib/ghc-9.2.8/site-local/pretty-simple-4.1.2.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/pretty-simple-4.1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pretty-simple
hs-libraries:         HSpretty-simple-4.1.2.0-3R2e5MieHhb1CbUFehFq5L
depends:
    base-4.16.4.0 containers-0.6.5.1 mtl-2.2.2
    prettyprinter-1.7.1-JEDC7ONR1vQJETgOTWpLZ0
    prettyprinter-ansi-terminal-1.1.3-4WG0PclEa1OHeT9lxo6Wrk
    text-1.2.5.0 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-pretty-simple/html/pretty-simple.haddock

haddock-html:         /usr/share/doc/haskell-pretty-simple/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
